.. _experimentGUI:

Experiment Information
======================

This component offers the main information about your experiment.

.. figure:: fig/fig_experiment.jpg
   :name: experiment_view
   :width: 100%
   :align: center
   :alt: experiment_view

   Experiment Information

At the top left you see the ``Autosubmit Searcher`` home link that will take you back to the :ref:`autosubmitGUIMP`, next to it you see the ``Home`` link that serves the same purpose, then you see the ``About`` link that takes you to a page with important information about the application (including the link to this documentation). Then you see the experiment name and ``status``, which is updated every 5 minutes. Next, you see the `run history` button, this button opens a panel that shows information about previous runs of the experiment, only works for experiments running the latest version of Autosubmit. Then, you see the ``esarchive status`` badge, it shows information about the current status of the `esarchive` file system. 

At the bottom you see some relevant metadata, including the ``branch`` of the ``model`` that was used in the experiment, the ``HPC name`` targeted by the experiment, the owner, the ``version`` that this experiment us running on, the ``DB`` version of Autosubmit, and the number of jobs in the experiment.

On the center you see the :ref:`treeRepresentation`, which is loaded automatically when you open this page.